@@ -1,9 +1,36 @@
 package Clustericious::Client::Object::DateTime;
 
+use strict;
+use warnings;
+
+# ABSTRACT: Clustericious DateTime object
+our $VERSION = '0.84'; # VERSION
+
+
+use DateTime::Format::ISO8601;
+
+
+sub new
+{
+    my $class = shift;
+    my ($datetime) = @_;
+
+    DateTime::Format::ISO8601->new->parse_datetime($datetime);
+}
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
 Clustericious::Client::Object::DateTime - Clustericious DateTime object
 
+=head1 VERSION
+
+version 0.84
+
 =head1 SYNOPSIS
 
  my $obj = Clustericious::Client::Object::DateTime->new('2000-01-01');
@@ -17,29 +44,28 @@ A simple wrapper around DateTime::Format::ISO8601 that provides a
 new() function that acts like Clustericious::Client::Object wants it
 to.
 
-=cut
-
-use strict;
-use warnings;
-
-use DateTime::Format::ISO8601;
-
-our $VERSION = '0.83';
-
 =head1 METHODS
 
 =head2 C<new>
 
  my $obj = Clustericious::Client::Object::DateTime->new('2000-01-01');
 
+=head1 AUTHOR
+
+original author: Curt Tilmes
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Brian Duggan
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub new
-{
-    my $class = shift;
-    my ($datetime) = @_;
-
-    DateTime::Format::ISO8601->new->parse_datetime($datetime);
-}
-
-1;
